@@ -5,7 +5,7 @@ extends 'Chart::Clicker::Renderer';
 
 use Graphics::Color::RGB;
 use Geometry::Primitive::Arc;
-use Graphics::Primitive::Stroke;
+use Graphics::Primitive::Brush;
 
 has 'border_color' => (
     is => 'rw',
@@ -13,16 +13,16 @@ has 'border_color' => (
     default => sub { Graphics::Color::RGB->new },
     coerce => 1
 );
-has 'stroke' => (
+has 'brush' => (
     is => 'rw',
-    isa => 'Graphics::Primitive::Stroke',
-    default => sub { Graphics::Primitive::Stroke->new() }
+    isa => 'Graphics::Primitive::Brush',
+    default => sub { Graphics::Primitive::Brush->new }
 );
 
 my $TO_RAD = (4 * atan2(1, 1)) / 180;
 
 override('prepare', sub {
-    my $self = shift();
+    my $self = shift;
 
     super;
 
@@ -30,9 +30,9 @@ override('prepare', sub {
 
     my $dses = $clicker->get_datasets_for_context($self->context);
     foreach my $ds (@{ $dses }) {
-        foreach my $series (@{ $ds->series() }) {
-            foreach my $val (@{ $series->values() }) {
-                $self->{ACCUM}->{$series->name()} += $val;
+        foreach my $series (@{ $ds->series }) {
+            foreach my $val (@{ $series->values }) {
+                $self->{ACCUM}->{$series->name} += $val;
                 $self->{TOTAL} += $val;
             }
         }
@@ -40,25 +40,24 @@ override('prepare', sub {
 
 });
 
-override('draw', sub {
-    my $self = shift();
+override('pack', sub {
+    my $self = shift;
 
     my $clicker = $self->clicker;
-    my $cr = $clicker->cairo;
 
-    $self->{RADIUS} = $self->height();
-    if($self->width() < $self->height()) {
-        $self->{RADIUS} = $self->width();
+    $self->{RADIUS} = $self->height;
+    if($self->width < $self->height) {
+        $self->{RADIUS} = $self->width;
     }
 
     $self->{RADIUS} = $self->{RADIUS} / 2;
 
     # Take into acount the line around the edge when working out the radius
-    $self->{RADIUS} -= $self->stroke->width();
+    $self->{RADIUS} -= $self->brush->width;
 
-    my $height = $self->height();
+    my $height = $self->height;
     my $linewidth = 1;
-    my $midx = $self->width() / 2;
+    my $midx = $self->width / 2;
     my $midy = $height / 2;
     $self->{POS} = -90;
 
@@ -71,26 +70,28 @@ override('draw', sub {
             my $domain = $ctx->domain_axis;
             my $range = $ctx->range_axis;
 
-            $cr->set_line_cap($self->stroke->line_cap());
-            $cr->set_line_join($self->stroke->line_join());
-            $cr->set_line_width($self->stroke->width());
-
-            my $avg = $self->{ACCUM}->{$series->name()} / $self->{TOTAL};
+            my $avg = $self->{ACCUM}->{$series->name} / $self->{TOTAL};
             my $degs = ($avg * 360) + $self->{POS};
 
-            $cr->line_to($midx, $midy);
+            $self->move_to($midx, $midy);
+            $self->arc($self->{RADIUS}, $degs * $TO_RAD, $self->{POS} * $TO_RAD);
 
-            $cr->arc_negative($midx, $midy, $self->{RADIUS}, $degs * $TO_RAD, $self->{POS} * $TO_RAD);
-            $cr->line_to($midx, $midy);
-            $cr->close_path();
+            $self->close_path;
 
-            my $color = $clicker->color_allocator->next();
+            my $color = $clicker->color_allocator->next;
 
-            $cr->set_source_rgba($color->as_array_with_alpha());
-            $cr->fill_preserve();
+            my $fop = Graphics::Primitive::Operation::Fill->new(
+                preserve => 1
+            );
+            $fop->paint(Graphics::Primitive::Paint::Solid->new(
+                color => $color,
+            ));
+            $self->do($fop);
 
-            $cr->set_source_rgba($self->border_color->as_array_with_alpha());
-            $cr->stroke();
+            my $op = Graphics::Primitive::Operation::Stroke->new;
+            $op->brush($self->brush->clone);
+            $op->brush->color($self->border_color);
+            $self->do($op);
 
             $self->{POS} = $degs;
         }
@@ -117,10 +118,10 @@ of like-named Series are totaled and keys are ignored.
 
 =head1 SYNOPSIS
 
-  my $lr = Chart::Clicker::Renderer::Pie->new();
+  my $lr = Chart::Clicker::Renderer::Pie->new;
   # Optionally set the stroke
   $lr->options({
-    stroke => Graphics::Primitive::Stroke->new({
+    brush => Graphics::Primitive::Brush->new({
       ...
     })
   });
@@ -129,9 +130,9 @@ of like-named Series are totaled and keys are ignored.
 
 =over 4
 
-=item I<stroke>
+=item I<brush>
 
-Set a Stroke object to be used for the lines.
+Set a brush object to be used for the lines.
 
 =back
 
